lightkurve
==========

**A beautiful package for astronomical flux time series analysis in Python.**

|pypi-badge| |ci-badge| |appveyor-badge| |cov-badge| |doi-badge|

.. |pypi-badge| image:: https://img.shields.io/pypi/v/lightkurve.svg
                :target: https://pypi.python.org/pypi/lightkurve
.. |ci-badge| image:: https://travis-ci.org/KeplerGO/lightkurve.svg?branch=master
              :target: https://travis-ci.org/KeplerGO/lightkurve
.. |appveyor-badge| image:: https://ci.appveyor.com/api/projects/status/6jvv5d7a142gwm8a/branch/master?svg=true
                    :target: https://ci.appveyor.com/project/mirca/lightkurve
.. |cov-badge| image:: https://codecov.io/gh/KeplerGO/lightkurve/branch/master/graph/badge.svg
              :target: https://codecov.io/gh/KeplerGO/lightkurve
.. |doi-badge| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.835584.svg
              :target: https://doi.org/10.5281/zenodo.835584


*lightkurve* offers a user-friendly way to inspect and analyze astronomical flux time series data.
In particular, it is well-suited to analyze the pixels and lightcurves obtained by NASA's Kepler, K2, and TESS missions.

Documentation
-------------

Read the documentation at `http://lightkurve.keplerscience.org <http://lightkurve.keplerscience.org>`_.

Quickstart
----------

If you have a working version of Python 2 or 3 on your system
(we recommend `Anaconda Python <https://www.continuum.io/downloads>`_),
you can simply install the latest stable release of `lightcurve` using ``pip``::

    $ pip install lightkurve

With `lightkurve` installed, you can... TBC.

Contributing
------------

Users are welcome to open `issues <https://github.com/KeplerGO/lightkurve/issues>`_
or `pull requests <https://github.com/KeplerGO/lightkurve/pulls>`_.
You can also contact the development team via keplergo@mail.arc.nasa.gov


Citing
------

TBC
